@@ -78,6 +78,7 @@ public:
     bool callMulti(const QString& function, const QString& mName);
     bool callConditionFunction(std::string& function, const QString& mName);
     bool call_luafunction(void*);
+    double condenseMapLoad();
     bool compile(const QString& code, QString& error, const QString& name);
     bool compileScript(const QString&);
     void setAtcpTable(const QString&, const QString&);
@@ -149,6 +150,14 @@ public:
     static int getRooms(lua_State*);
     static int connectToServer(lua_State* L);
     static int sendIrc(lua_State*);
+    static int getIrcNick(lua_State*);
+    static int getIrcServer(lua_State*);
+    static int getIrcChannels(lua_State*);
+    static int getIrcConnectedHost(lua_State*);
+    static int setIrcNick(lua_State*);
+    static int setIrcServer(lua_State*);
+    static int setIrcChannels(lua_State*);
+    static int restartIrc(lua_State*);
     static int showUnzipProgress(lua_State*);
     static int setAppStyleSheet(lua_State*);
     static int setMainWindowSize(lua_State* L);
