@@ -50,8 +50,9 @@ TRoomDB::TRoomDB( TMap * pMap )
 
 TRoom* TRoomDB::getRoom(int id)
 {
-    if (id < 0)
+    if (id < 0) {
         return 0;
+    }
     auto i = rooms.find(id);
     if (i != rooms.end() && i.key() == id) {
         return i.value();
@@ -220,30 +221,42 @@ bool TRoomDB::__removeRoom(int id)
             }
             TRoom* r = getRoom(i.value());
             if (r) {
-                if (r->getNorth() == id)
+                if (r->getNorth() == id) {
                     r->setNorth(-1);
-                if (r->getNortheast() == id)
+                }
+                if (r->getNortheast() == id) {
                     r->setNortheast(-1);
-                if (r->getNorthwest() == id)
+                }
+                if (r->getNorthwest() == id) {
                     r->setNorthwest(-1);
-                if (r->getEast() == id)
+                }
+                if (r->getEast() == id) {
                     r->setEast(-1);
-                if (r->getWest() == id)
+                }
+                if (r->getWest() == id) {
                     r->setWest(-1);
-                if (r->getSouth() == id)
+                }
+                if (r->getSouth() == id) {
                     r->setSouth(-1);
-                if (r->getSoutheast() == id)
+                }
+                if (r->getSoutheast() == id) {
                     r->setSoutheast(-1);
-                if (r->getSouthwest() == id)
+                }
+                if (r->getSouthwest() == id) {
                     r->setSouthwest(-1);
-                if (r->getUp() == id)
+                }
+                if (r->getUp() == id) {
                     r->setUp(-1);
-                if (r->getDown() == id)
+                }
+                if (r->getDown() == id) {
                     r->setDown(-1);
-                if (r->getIn() == id)
+                }
+                if (r->getIn() == id) {
                     r->setIn(-1);
-                if (r->getOut() == id)
+                }
+                if (r->getOut() == id) {
                     r->setOut(-1);
+                }
                 r->removeAllSpecialExitsToRoom(id);
             }
             ++i;
@@ -259,8 +272,9 @@ bool TRoomDB::__removeRoom(int id)
         }
         int areaID = pR->getArea();
         TArea* pA = getArea(areaID);
-        if (pA)
+        if (pA) {
             pA->removeRoom(id);
+        }
         if ((!mpTempRoomDeletionSet) || mpTempRoomDeletionSet->size() == 1) { // if NOT deleting multiple rooms
             entranceMap.remove(id);                                           // Only removes matching keys
             deleteValuesFromEntranceMap(id);                                  // Needed to remove matching values
@@ -392,8 +406,9 @@ void TRoomDB::buildAreas()
         it.next();
         int id = it.key();
         TRoom* pR = getRoom(id);
-        if (!pR)
+        if (!pR) {
             continue;
+        }
         TArea* pA = getArea(pR->getArea());
         if (!pA) {
             areas[pR->getArea()] = new TArea(mpMap, this);
@@ -582,7 +597,7 @@ QList<int> TRoomDB::getAreaIDList()
  *    lines (no key for an normal or special exit that isn't there), locks
  *    (beware of duplicate QList<T> elements), room and exit weights (can only
  *    have a weight on an actual exit).
- *10) Validate TArea elements: ebenen (beware of duplicate QList<T> elements)
+ * 10) Validate TArea elements: ebenen (beware of duplicate QList<T> elements)
  */
 void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRemapping)
 {
@@ -601,7 +616,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
             itRoom.next();
             TRoom* pR = itRoom.value();
             if (!pR) {
-                if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+                if (mudlet::self()->showMapAuditErrors()) {
                     QString warnMsg = tr("[ WARN ]  - Problem with data structure associated with room id: %1 - that\n"
                                          "room's data has been lost so the id is now being deleted.  This\n"
                                          "suggests serious problems with the currently running version of\n"
@@ -656,7 +671,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
         }
 
         if (!areas.contains(usedAreaId)) {
-            if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+            if (mudlet::self()->showMapAuditErrors()) {
                 QString warnMsg = tr("[ ALERT ] - Area with id: %1 expected but not found, will be created.").arg(usedAreaId);
                 mpMap->postMessage(warnMsg);
             }
@@ -688,27 +703,27 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
     // * WILL NOT be in TRoomDB::areas - as that is the source of the error this
     // bit of the task being addressed here is fixing
     if (!missingAreasNeeded.isEmpty()) {
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
-            QString alertMsg = tr( "[ ALERT ] - %n area(s) detected as missing in map: adding it/them in.\n"
-                                   " Look for further messsages related to the rooms that are supposed\n"
-                                   " to be in this/these area(s)...",
-                                   "Making use of %n to allow quantity dependent message form 8-) !",
-                                   missingAreasNeeded.count() );
+        if (mudlet::self()->showMapAuditErrors()) {
+            QString alertMsg = tr("[ ALERT ] - %n area(s) detected as missing in map: adding it/them in.\n"
+                                  " Look for further messsages related to the rooms that are supposed\n"
+                                  " to be in this/these area(s)...",
+                                  "Making use of %n to allow quantity dependent message form 8-) !",
+                                  missingAreasNeeded.count());
             mpMap->postMessage(alertMsg);
         }
         mpMap->appendErrorMsgWithNoLf(tr("[ ALERT ] - %n area(s) detected as missing in map: adding it/them in.\n"
                                          " Look for further messsages related to the rooms that is/are supposed to\n"
                                          " be in this/these area(s)...",
                                          "Making use of %n to allow quantity dependent message form 8-) !",
-                                         missingAreasNeeded.count() ),
-                              true);
+                                         missingAreasNeeded.count()),
+                                      true);
 
         QString infoMsg;
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             infoMsg = tr("[ INFO ]  - The missing area(s) are now called:\n"
                          "(ID) ==> \"name\"",
                          "Making use of %n to allow quantity dependent message form 8-) !",
-                         missingAreasNeeded.count() );
+                         missingAreasNeeded.count());
         }
 
         if (missingAreasNeeded.count() > 1) {
@@ -730,7 +745,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
         // in the debugger a little clearer...
         missingAreasNeeded.clear();
 
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             mpMap->postMessage(infoMsg);
         }
         mpMap->appendErrorMsg(infoMsg, true);
@@ -739,7 +754,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
     // START OF TASK 5.1
     // Now process problem areaIds
     if (!areaRemapping.isEmpty()) {
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             QString alertMsg = tr("[ ALERT ] - Bad, (less than +1 and not the reserved -1) area ids found (count: %1)\n"
                                   "in map, now working out what new id numbers to use...")
                                        .arg(areaRemapping.count());
@@ -751,7 +766,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
                               true);
 
         QString infoMsg;
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             infoMsg = tr("[ INFO ]  - The renumbered area ids will be:\n"
                          "Old ==> New");
         }
@@ -766,7 +781,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
             } while (areas.contains(++replacementAreaId));
             // Insert replacement value into hash
             itRemappedArea.setValue(replacementAreaId);
-            if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+            if (mudlet::self()->showMapAuditErrors()) {
                 infoMsg.append(QStringLiteral("\n%1 ==> %2").arg(QString::number(faultyAreaId), QString::number(replacementAreaId)));
             }
 
@@ -809,11 +824,11 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
 
             pA->mIsDirty = true;
         }
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             mpMap->postMessage(infoMsg);
         }
     } else {
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             QString infoMsg = tr("[ INFO ]  - Area id numbering is satisfactory.");
             mpMap->postMessage(infoMsg);
         }
@@ -824,7 +839,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
 
     // Now complete TASK 1 - find the new room Ids to use
     if (!roomRemapping.isEmpty()) {
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             QString alertMsg = tr("[ ALERT ] - Bad, (less than +1) room ids found (count: %1) in map, now working\n"
                                   "out what new id numbers to use.")
                                        .arg(roomRemapping.count());
@@ -836,7 +851,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
                               true);
 
         QString infoMsg;
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             infoMsg = tr("[ INFO ]  - The renumbered rooms will be:\n");
         }
         QMutableHashIterator<int, int> itRenumberedRoomId(roomRemapping);
@@ -849,14 +864,14 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
 
             itRenumberedRoomId.setValue(newRoomId); // Update the QHash
             validUsedRoomIds.insert(newRoomId);
-            if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+            if (mudlet::self()->showMapAuditErrors()) {
                 infoMsg.append(QStringLiteral("%1 ==> %2").arg(QString::number(itRenumberedRoomId.key()), QString::number(itRenumberedRoomId.value())));
             }
 
             mpMap->appendRoomErrorMsg(itRenumberedRoomId.key(), tr("[ INFO ]  - This room with the bad id was renumbered to: %1.").arg(itRenumberedRoomId.value()), true);
             mpMap->appendRoomErrorMsg(itRenumberedRoomId.value(), tr("[ INFO ]  - This room was renumbered from the bad id: %1.").arg(itRenumberedRoomId.key()), true);
         }
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             mpMap->postMessage(infoMsg);
         }
 
@@ -889,7 +904,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
             rooms.insert(newRoomId, pR);
         }
     } else {
-        if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+        if (mudlet::self()->showMapAuditErrors()) {
             QString infoMsg = tr("[ INFO ]  - Room id numbering is satisfactory.");
             mpMap->postMessage(infoMsg);
         }
@@ -909,7 +924,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
             unsigned int _listCount = pR->exitStubs.count();
             QSet<int> _set = pR->exitStubs.toSet();
             if (_set.count() < _listCount) {
-                if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+                if (mudlet::self()->showMapAuditErrors()) {
                     QString infoMsg = tr("[ INFO ]  - Duplicate exit stub identifiers found in room id: %1, this is an\n"
                                          "anomaly but has been cleaned up easily.")
                                               .arg(itRoom.key());
@@ -923,7 +938,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
             _listCount = pR->exitLocks.count();
             _set = pR->exitLocks.toSet();
             if (_set.count() < _listCount) {
-                if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+                if (mudlet::self()->showMapAuditErrors()) {
                     QString infoMsg = tr("[ INFO ]  - Duplicate exit lock identifiers found in room id: %1, this is an\n"
                                          "anomaly but has been cleaned up easily.")
                                               .arg(itRoom.key());
@@ -966,12 +981,12 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
             // Now compare pA->rooms to areaRoomMultiHash.values( itArea.key() )
             QSet<int> foundRooms = areaRoomMultiHash.values(itArea.key()).toSet();
             QSetIterator<int> itFoundRoom(foundRooms);
-// Original form of code which was slower because the two sets of rooms were
-// compared TWICE:
-//            extraRooms = pA->rooms;
-//            extraRooms.subtract( foundRooms );
-//            missingRooms = foundRooms;
-//            missingRooms.subtract( pA->rooms );
+            // Original form of code which was slower because the two sets of rooms were
+            // compared TWICE:
+            //            extraRooms = pA->rooms;
+            //            extraRooms.subtract( foundRooms );
+            //            missingRooms = foundRooms;
+            //            missingRooms.subtract( pA->rooms );
 
             // Revised code that only makes one pass
             QSet<int> extraRooms(pA->rooms); //Take common rooms from here so that any left are the "extras"
@@ -1005,7 +1020,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
                                                       .arg(itArea.key()),
                                               true);
                 }
-                if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+                if (mudlet::self()->showMapAuditErrors()) {
                     QString infoMsg = tr("[ INFO ]  - In area with id: %1 there were %2 rooms missing from those it\n"
                                          "should be recording as possessing, they were:\n%3\nthey have been added.")
                                               .arg(itArea.key())
@@ -1040,7 +1055,7 @@ void TRoomDB::auditRooms(QHash<int, int>& roomRemapping, QHash<int, int>& areaRe
                                                       .arg(itArea.key()),
                                               true);
                 }
-                if (mudlet::self()->getAuditErrorsToConsoleEnabled()) {
+                if (mudlet::self()->showMapAuditErrors()) {
                     QString infoMsg = tr("[ INFO ]  - In area with id: %1 there were %2 extra rooms compared to those it\n"
                                          "should be recording as possessing, they were:\n%3\nthey have been removed.")
                                               .arg(itArea.key())
@@ -1076,7 +1091,7 @@ void TRoomDB::clearMapDB()
         delete room; // Uses the internally held value of the room Id
                      // (TRoom::id) to call TRoomDB::__removeRoom(id)
     }
-//    assert( rooms.size() == 0 ); // Pointless as rooms.clear() will have achieved the test condition
+    //    assert( rooms.size() == 0 ); // Pointless as rooms.clear() will have achieved the test condition
 
     QList<TArea*> areaList = getAreaPtrList();
     for (auto area : areaList) {
@@ -1147,7 +1162,8 @@ void TRoomDB::restoreAreaMap(QDataStream& ifs)
         QString extraTextForMatchingSuffixAlreadyUsed;
         QString detailText;
         if (isMatchingSuffixAlreadyPresent) {
-            extraTextForMatchingSuffixAlreadyUsed = tr(R"(It has been detected that "_###" form suffixes have already been used, for simplicity in the renaming algorithm these will have been removed and possibly changed as Mudlet sorts this matter out, if a number assigned in this way <b>is</b> important to you, you can change it back, provided you rename the area that has been allocated the suffix that was wanted first...!</p>)");
+            extraTextForMatchingSuffixAlreadyUsed = tr(
+                    R"(It has been detected that "_###" form suffixes have already been used, for simplicity in the renaming algorithm these will have been removed and possibly changed as Mudlet sorts this matter out, if a number assigned in this way <b>is</b> important to you, you can change it back, provided you rename the area that has been allocated the suffix that was wanted first...!</p>)");
         }
         if (renamedMap.size()) {
             detailText = tr("[  OK  ]  - The changes made are:\n"
@@ -1183,8 +1199,7 @@ void TRoomDB::restoreAreaMap(QDataStream& ifs)
                                  "another that exists at the time.\n"
                                  "  If there were more than one area without a name then all but the\n"
                                  "first will also gain a suffix in this manner.\n"
-                                 "%2")
-                                      .arg(mUnnamedAreaName, extraTextForMatchingSuffixAlreadyUsed);
+                                 "%2").arg(mUnnamedAreaName, extraTextForMatchingSuffixAlreadyUsed);
         } else if (renamedMap.size()) {
             // Duplicates but no unnnamed area
             alertText = tr("[ ALERT ] - Duplicate area names detected in the Map file!");
