@@ -150,7 +150,7 @@ bool XMLexport::writeModuleXML(QIODevice* device, QString moduleName)
             if (!(*it) || (*it)->mPackageName != moduleName) {
                 continue;
             }
-            if (!(*it)->isTempTrigger() && (*it)->mModuleMember) {
+            if (!(*it)->isTemporary() && (*it)->mModuleMember) {
                 if (!writeTrigger(*it)) {
                     isOk = false;
                 } else {
@@ -171,7 +171,7 @@ bool XMLexport::writeModuleXML(QIODevice* device, QString moduleName)
             if (!(*it) || (*it)->mPackageName != moduleName) {
                 continue;
             }
-            if (!(*it)->isTempTimer() && (*it)->mModuleMember) {
+            if (!(*it)->isTemporary() && (*it)->mModuleMember) {
                 if (!writeTimer(*it)) {
                     isOk = false;
                 } else {
@@ -192,7 +192,7 @@ bool XMLexport::writeModuleXML(QIODevice* device, QString moduleName)
             if (!(*it) || (*it)->mPackageName != moduleName) {
                 continue;
             }
-            if (!(*it)->isTempAlias() && (*it)->mModuleMember) {
+            if (!(*it)->isTemporary() && (*it)->mModuleMember) {
                 if (!writeAlias(*it)) {
                     isOk = false;
                 } else {
@@ -255,7 +255,7 @@ bool XMLexport::writeModuleXML(QIODevice* device, QString moduleName)
             if (!(*it) || (*it)->mPackageName != moduleName) {
                 continue;
             }
-            if (!(*it)->isTempKey() && (*it)->mModuleMember) {
+            if (!(*it)->isTemporary() && (*it)->mModuleMember) {
                 if (!writeKey(*it)) {
                     isOk = false;
                 } else {
@@ -351,6 +351,10 @@ bool XMLexport::writeHost(Host* pHost)
     writeAttribute("mShowRoomIDs", pHost->mShowRoomID ? "yes" : "no");
     writeAttribute("mShowPanel", pHost->mShowPanel ? "yes" : "no");
     writeAttribute("mHaveMapperScript", pHost->mHaveMapperScript ? "yes" : "no");
+    writeAttribute("mEditorTheme", pHost->mEditorTheme);
+    writeAttribute("mEditorThemeFile", pHost->mEditorThemeFile);
+    writeAttribute("mThemePreviewItemID", QString::number(pHost->mThemePreviewItemID));
+    writeAttribute("mThemePreviewType", pHost->mThemePreviewType);
     QString ignore;
     QSetIterator<QChar> it(pHost->mDoubleClickIgnore);
     while (it.hasNext()) {
@@ -471,7 +475,7 @@ bool XMLexport::writeHost(Host* pHost)
             if (!(*it) || (*it)->mModuleMember) {
                 continue;
             }
-            if (!(*it)->isTempTrigger()) {
+            if (!(*it)->isTemporary()) {
                 if (!writeTrigger(*it)) {
                     isOk = false;
                 }
@@ -486,7 +490,7 @@ bool XMLexport::writeHost(Host* pHost)
             if (!(*it) || (*it)->mModuleMember) {
                 continue;
             }
-            if (!(*it)->isTempTimer()) {
+            if (!(*it)->isTemporary()) {
                 if (!writeTimer(*it)) {
                     isOk = false;
                 }
@@ -501,7 +505,7 @@ bool XMLexport::writeHost(Host* pHost)
             if (!(*it) || (*it)->mModuleMember) {
                 continue;
             }
-            if (!(*it)->isTempAlias()) {
+            if (!(*it)->isTemporary()) {
                 if (!writeAlias(*it)) {
                     isOk = false;
                 }
@@ -539,7 +543,7 @@ bool XMLexport::writeHost(Host* pHost)
     if (isOk) {
         writeStartElement("KeyPackage");
         for( auto it = pHost->mKeyUnit.mKeyRootNodeList.begin(); isOk && it != pHost->mKeyUnit.mKeyRootNodeList.end(); ++it ) {
-            if( ! (*it) || (*it)->isTempKey() || (*it)->mModuleMember) {
+            if( ! (*it) || (*it)->isTemporary() || (*it)->mModuleMember) {
                 continue;
             }
             if (!writeKey(*it)) {
@@ -641,7 +645,7 @@ bool XMLexport::writeGenericPackage(Host* pHost)
     if (isOk) {
         writeStartElement("TriggerPackage");
         for (auto it = pHost->mTriggerUnit.mTriggerRootNodeList.begin(); isOk && it != pHost->mTriggerUnit.mTriggerRootNodeList.end(); ++it) {
-            if (!(*it) || (*it)->isTempTrigger()) {
+            if (!(*it) || (*it)->isTemporary()) {
                 continue;
             }
             if (!writeTrigger(*it)) {
@@ -654,7 +658,7 @@ bool XMLexport::writeGenericPackage(Host* pHost)
     if (isOk) {
         writeStartElement("TimerPackage");
         for (auto it = pHost->mTimerUnit.mTimerRootNodeList.begin(); isOk && it != pHost->mTimerUnit.mTimerRootNodeList.end(); ++it) {
-            if (!(*it) || (*it)->isTempTimer()) {
+            if (!(*it) || (*it)->isTemporary()) {
                 continue;
             }
             if (!writeTimer(*it)) {
@@ -667,7 +671,7 @@ bool XMLexport::writeGenericPackage(Host* pHost)
     if (isOk) {
         writeStartElement("AliasPackage");
         for (auto it = pHost->mAliasUnit.mAliasRootNodeList.begin(); isOk && it != pHost->mAliasUnit.mAliasRootNodeList.end(); ++it) {
-            if (!(*it) || (*it)->isTempAlias()) {
+            if (!(*it) || (*it)->isTemporary()) {
                 continue;
             }
             if (!writeAlias(*it)) {
@@ -706,7 +710,7 @@ bool XMLexport::writeGenericPackage(Host* pHost)
     if( isOk ) {
         writeStartElement( "KeyPackage" );
         for( auto it = pHost->mKeyUnit.mKeyRootNodeList.begin(); isOk && it != pHost->mKeyUnit.mKeyRootNodeList.end(); ++it ) {
-            if( ! (*it) || (*it)->isTempKey() ) {
+            if( ! (*it) || (*it)->isTemporary() ) {
                 continue;
             }
             if (!writeKey(*it)) {
@@ -748,11 +752,11 @@ bool XMLexport::writeTrigger(TTrigger* pT)
 {
     bool isOk = true;
     if (!pT->mModuleMasterFolder && pT->exportItem) {
-        writeStartElement(pT->mIsFolder ? "TriggerGroup" : "Trigger");
+        writeStartElement(pT->isFolder() ? "TriggerGroup" : "Trigger");
 
         writeAttribute("isActive", pT->shouldBeActive() ? "yes" : "no");
-        writeAttribute("isFolder", pT->mIsFolder ? "yes" : "no");
-        writeAttribute("isTempTrigger", pT->mIsTempTrigger ? "yes" : "no");
+        writeAttribute("isFolder", pT->isFolder() ? "yes" : "no");
+        writeAttribute("isTempTrigger", pT->isTemporary() ? "yes" : "no");
         writeAttribute("isMultiline", pT->mIsMultiline ? "yes" : "no");
         writeAttribute("isPerlSlashGOption", pT->mPerlSlashGOption ? "yes" : "no");
         writeAttribute("isColorizerTrigger", pT->mIsColorizerTrigger ? "yes" : "no");
@@ -845,10 +849,10 @@ bool XMLexport::writeAlias(TAlias* pT)
 {
     bool isOk = true;
     if (!pT->mModuleMasterFolder && pT->exportItem) {
-        writeStartElement(pT->mIsFolder ? "AliasGroup" : "Alias");
+        writeStartElement(pT->isFolder() ? "AliasGroup" : "Alias");
 
         writeAttribute("isActive", pT->shouldBeActive() ? "yes" : "no");
-        writeAttribute("isFolder", pT->mIsFolder ? "yes" : "no");
+        writeAttribute("isFolder", pT->isFolder() ? "yes" : "no");
 
         { // Blocked so that indentation reflects that of the XML file
             writeTextElement("name", pT->mName);
@@ -902,10 +906,10 @@ bool XMLexport::writeAction(TAction* pT)
 {
     bool isOk = true;
     if (!pT->mModuleMasterFolder && pT->exportItem) {
-        writeStartElement(pT->mIsFolder ? "ActionGroup" : "Action");
+        writeStartElement(pT->isFolder() ? "ActionGroup" : "Action");
 
         writeAttribute("isActive", pT->shouldBeActive() ? "yes" : "no");
-        writeAttribute("isFolder", pT->mIsFolder ? "yes" : "no");
+        writeAttribute("isFolder", pT->isFolder() ? "yes" : "no");
         writeAttribute("isPushButton", pT->mIsPushDownButton ? "yes" : "no");
         writeAttribute("isFlatButton", pT->mButtonFlat ? "yes" : "no");
         writeAttribute("useCustomLayout", pT->mUseCustomLayout ? "yes" : "no");
@@ -976,11 +980,11 @@ bool XMLexport::writeTimer(TTimer* pT)
 {
     bool isOk = true;
     if (!pT->mModuleMasterFolder && pT->exportItem) {
-        writeStartElement(pT->mIsFolder ? "TimerGroup" : "Timer");
+        writeStartElement(pT->isFolder() ? "TimerGroup" : "Timer");
 
         writeAttribute("isActive", pT->shouldBeActive() ? "yes" : "no");
-        writeAttribute("isFolder", pT->mIsFolder ? "yes" : "no");
-        writeAttribute("isTempTimer", pT->mIsTempTimer ? "yes" : "no");
+        writeAttribute("isFolder", pT->isFolder() ? "yes" : "no");
+        writeAttribute("isTempTimer", pT->isTemporary() ? "yes" : "no");
         writeAttribute("isOffsetTimer", pT->isOffsetTimer() ? "yes" : "no");
 
         { // Blocked so that indentation reflects that of the XML file
@@ -1036,10 +1040,10 @@ bool XMLexport::writeScript(TScript* pT)
 {
     bool isOk = true;
     if (!pT->mModuleMasterFolder && pT->exportItem) {
-        writeStartElement(pT->mIsFolder ? "ScriptGroup" : "Script");
+        writeStartElement(pT->isFolder() ? "ScriptGroup" : "Script");
 
         writeAttribute("isActive", pT->shouldBeActive() ? "yes" : "no");
-        writeAttribute("isFolder", pT->mIsFolder ? "yes" : "no");
+        writeAttribute("isFolder", pT->isFolder() ? "yes" : "no");
 
         { // Blocked so that indentation reflects that of the XML file
             writeTextElement("name", pT->mName);
@@ -1098,10 +1102,10 @@ bool XMLexport::writeKey(TKey* pT)
 {
     bool isOk = true;
     if (!pT->mModuleMasterFolder && pT->exportItem) {
-        writeStartElement(pT->mIsFolder ? "KeyGroup" : "Key");
+        writeStartElement(pT->isFolder() ? "KeyGroup" : "Key");
 
         writeAttribute("isActive", pT->shouldBeActive() ? "yes" : "no");
-        writeAttribute("isFolder", pT->mIsFolder ? "yes" : "no");
+        writeAttribute("isFolder", pT->isFolder() ? "yes" : "no");
 
         { // Blocked so that indentation reflects that of the XML file
             writeTextElement("name", pT->mName);
@@ -1128,7 +1132,7 @@ bool XMLexport::writeKey(TKey* pT)
     return (isOk && (!hasError()));
 }
 
-bool XMLexport::writeScriptElement(const QString & script)
+bool XMLexport::writeScriptElement(const QString& script)
 {
     QString localScript = script;
     localScript.replace(QChar('\x01'), QStringLiteral("\xFFFC\x2401")); // SOH
@@ -1161,6 +1165,6 @@ bool XMLexport::writeScriptElement(const QString & script)
     localScript.replace(QChar('\x1F'), QStringLiteral("\xFFFC\x241F")); // US
     localScript.replace(QChar('\x7F'), QStringLiteral("\xFFFC\x2421")); // DEL
     writeTextElement(QLatin1String("script"), localScript);
-    
+
     return (!hasError());
 }
